┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/bookmarkselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkselector.h')
-rw-r--r--src/bookmarkselector.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/bookmarkselector.h b/src/bookmarkselector.h
index 50fc2e3e5..b904a0d57 100644
--- a/src/bookmarkselector.h
+++ b/src/bookmarkselector.h
@@ -24,7 +24,7 @@
#include <urlbutton.h>
class UrlNavigator;
-class Q3PopupMenu;
+class KMenu;
class KUrl;
/**
@@ -85,15 +85,15 @@ protected:
private slots:
/**
* Updates the selected index and the icon if a bookmark
* has been activated by the user.
*/
- void slotBookmarkActivated(int index);
+ void activateBookmark(QAction* action);
private:
int m_selectedIndex;
UrlNavigator* m_urlNavigator;
- Q3PopupMenu* m_bookmarksMenu;
+ KMenu* m_bookmarksMenu;
};
@@ -85,15 +85,15 @@ protected:
private slots:
/**
- * Updates the selected index and the icon if a bookmark
- * has been activated by the user.
+ * Updates the selected index and the icon to the bookmark
+ * which is indicated by the triggered action \a action.
*/